@@ -1,3 +1,4 @@
+import os
 import re
 import subprocess
 from email.utils import parseaddr
@@ -425,6 +426,7 @@ What GUI toolkit do you want to use for this project?""",
             options=[
                 'Toga',
                 'PySide2 (does not support iOS/Android deployment)',
+                'PySide6 (does not support iOS/Android deployment)',
                 'PursuedPyBear (does not support iOS/Android deployment)',
                 'None',
             ],
@@ -484,7 +486,7 @@ What GUI toolkit do you want to use for this project?""",
             self.cookiecutter(
                 str(cached_template),
                 no_input=True,
-                output_dir=str(self.base_path),
+                output_dir=os.fsdecode(self.base_path),
                 checkout="v0.3",
                 extra_context=context
             )
