@@ -1,3 +1,4 @@
+import os
 import re
 import shutil
 import subprocess
@@ -84,7 +85,7 @@ class AndroidSDK:
     def env(self):
         return {
             **self.command.os.environ,
-            "ANDROID_SDK_ROOT": str(self.root_path),
+            "ANDROID_SDK_ROOT": os.fsdecode(self.root_path),
             "JAVA_HOME": str(self.jdk.java_home),
         }
 
@@ -175,7 +176,7 @@ class AndroidSDK:
         """
         return self.sdkmanager_path.exists() and (
             self.command.host_os == "Windows"
-            or self.command.os.access(str(self.sdkmanager_path), self.command.os.X_OK)
+            or self.command.os.access(self.sdkmanager_path, self.command.os.X_OK)
         )
 
     @property
@@ -199,7 +200,8 @@ class AndroidSDK:
 
         try:
             print("Install Android SDK...")
-            self.command.shutil.unpack_archive(str(sdk_zip_path), extract_dir=str(self.root_path))
+            # TODO: Py3.6 compatibility; os.fsdecode not required in Py3.7
+            self.command.shutil.unpack_archive(os.fsdecode(sdk_zip_path), extract_dir=os.fsdecode(self.root_path))
         except (shutil.ReadError, EOFError):
             raise BriefcaseCommandError(
                 """\
@@ -218,7 +220,7 @@ Delete {sdk_zip_path} and run briefcase again.""".format(
         # On non-Windows, we manually fix permissions.
         if self.command.host_os != "Windows":
             for binpath in (self.root_path / "tools" / "bin").glob("*"):
-                if not self.command.os.access(str(binpath), self.command.os.X_OK):
+                if not self.command.os.access(binpath, self.command.os.X_OK):
                     binpath.chmod(0o755)
 
         # Licences must be accepted.
@@ -230,7 +232,7 @@ Delete {sdk_zip_path} and run briefcase again.""".format(
             # Using subprocess.run() with no I/O redirection so the user sees
             # the full output and can send input.
             self.command.subprocess.run(
-                [str(self.sdkmanager_path), "--update"], env=self.env, check=True,
+                [os.fsdecode(self.sdkmanager_path), "--update"], env=self.env, check=True,
             )
         except subprocess.CalledProcessError:
             raise BriefcaseCommandError(
@@ -272,7 +274,7 @@ Delete {sdk_zip_path} and run briefcase again.""".format(
             # Using subprocess.run() with no I/O redirection so the user sees
             # the full output and can send input.
             self.command.subprocess.run(
-                [str(self.sdkmanager_path), "--licenses"], env=self.env, check=True,
+                [os.fsdecode(self.sdkmanager_path), "--licenses"], env=self.env, check=True,
             )
         except subprocess.CalledProcessError:
             raise BriefcaseCommandError(
@@ -307,7 +309,7 @@ Delete {sdk_zip_path} and run briefcase again.""".format(
             # displaying it only if an exception occurs.
             self.command.subprocess.run(
                 [
-                    str(self.sdkmanager_path),
+                    os.fsdecode(self.sdkmanager_path),
                     "platforms;android-28",
                     "system-images;android-28;default;x86",
                     "emulator",
@@ -329,7 +331,7 @@ Delete {sdk_zip_path} and run briefcase again.""".format(
             # Capture `stderr` so that if the process exits with failure, the
             # stderr data is in `e.output`.
             output = self.command.subprocess.check_output(
-                [str(self.emulator_path), "-list-avds"],
+                [os.fsdecode(self.emulator_path), "-list-avds"],
                 universal_newlines=True,
                 stderr=subprocess.STDOUT,
             ).strip()
@@ -349,7 +351,7 @@ Delete {sdk_zip_path} and run briefcase again.""".format(
             # Capture `stderr` so that if the process exits with failure, the
             # stderr data is in `e.output`.
             output = self.command.subprocess.check_output(
-                [str(self.adb_path), "devices", "-l"],
+                [os.fsdecode(self.adb_path), "devices", "-l"],
                 universal_newlines=True,
                 stderr=subprocess.STDOUT,
             ).strip()
@@ -611,7 +613,7 @@ An emulator named '{avd}' already exists.
             print()
             self.command.subprocess.check_output(
                 [
-                    str(self.avdmanager_path),
+                    os.fsdecode(self.avdmanager_path),
                     "--verbose",
                     "create", "avd",
                     "--name", avd,
@@ -648,9 +650,10 @@ An emulator named '{avd}' already exists.
 
             # Unpack skin archive
             try:
+                # TODO: Py3.6 compatibility; os.fsdecode not required in Py3.7
                 self.command.shutil.unpack_archive(
-                    str(skin_tgz_path),
-                    extract_dir=str(skin_path)
+                    os.fsdecode(skin_tgz_path),
+                    extract_dir=os.fsdecode(skin_path)
                 )
             except (shutil.ReadError, EOFError):
                 raise BriefcaseCommandError(
@@ -694,7 +697,7 @@ In future, you can specify this device by running:
             print("Starting emulator {avd}...".format(avd=avd))
             emulator_popen = self.command.subprocess.Popen(
                 [
-                    str(self.emulator_path),
+                    os.fsdecode(self.emulator_path),
                     '@' + avd,
                     '-dns-server', '8.8.8.8'
                 ],
@@ -850,11 +853,11 @@ class ADB:
             # stderr data is in `e.output`.
             return self.command.subprocess.check_output(
                 [
-                    str(self.android_sdk.adb_path),
+                    os.fsdecode(self.android_sdk.adb_path),
                     "-s",
                     self.device,
                 ]
-                + list(arguments),
+                + [(os.fsdecode(arg) if isinstance(arg, Path) else arg) for arg in arguments],
                 universal_newlines=True,
                 stderr=subprocess.STDOUT,
             )
@@ -872,7 +875,7 @@ class ADB:
         Returns `None` on success; raises an exception on failure.
         """
         try:
-            self.run("install", str(apk_path))
+            self.run("install", apk_path)
         except subprocess.CalledProcessError:
             raise BriefcaseCommandError(
                 "Unable to install APK {apk_path} on {device}".format(
@@ -950,3 +953,43 @@ class ADB:
                     package=package, activity=activity, device=self.device,
                 )
             )
+
+    def clear_log(self):
+        """
+        Clear the log for the device.
+
+        Returns `None` on success; raises an exception on failure.
+        """
+        try:
+            # Invoke `adb logcat -c`
+            self.run("logcat", "-c")
+        except subprocess.CalledProcessError:
+            raise BriefcaseCommandError(
+                "Unable to clear log on {device}".format(
+                    device=self.device,
+                )
+            )
+
+    def logcat(self):
+        """
+        Start tailing the adb log for the device.
+        """
+        try:
+            # Using subprocess.run() with no I/O redirection so the user sees
+            # the full output and can send input.
+            self.command.subprocess.run(
+                [
+                    os.fsdecode(self.android_sdk.adb_path),
+                    "-s",
+                    self.device,
+                    "logcat",
+                    "-s",
+                    "MainActivity:*",
+                    "stdio:*",
+                    "Python:*",
+                ],
+                env=self.android_sdk.env,
+                check=True,
+            )
+        except subprocess.CalledProcessError:
+            raise BriefcaseCommandError("Error starting ADB logcat.")
