@@ -110,11 +110,11 @@ class GradleBuildCommand(GradleMixin, BuildCommand):
                 # Windows needs the full path to `gradlew`; macOS & Linux can find it
                 # via `./gradlew`. For simplicity of implementation, we always provide
                 # the full path.
-                [str(self.gradlew_path(app)), "assembleDebug"],
+                [self.gradlew_path(app), "assembleDebug"],
                 env=self.android_sdk.env,
                 # Set working directory so gradle can use the app bundle path as its
                 # project root, i.e., to avoid 'Task assembleDebug not found'.
-                cwd=str(self.bundle_path(app)),
+                cwd=self.bundle_path(app),
                 check=True
             )
         except subprocess.CalledProcessError:
@@ -190,11 +190,22 @@ class GradleRunCommand(GradleMixin, RunCommand):
         ))
         adb.install_apk(self.binary_path(app))
 
+        print()
+        print("[{app.app_name}] Clearing device log...".format(
+            app=app,
+        ))
+        adb.clear_log()
+
         # To start the app, we launch `org.beeware.android.MainActivity`.
         print()
         print("[{app.app_name}] Launching app...".format(app=app))
         adb.start_app(package, "org.beeware.android.MainActivity")
 
+        print()
+        print("[{app.app_name}] Following device log output (type CTRL-C to stop log)...".format(app=app))
+        print("=" * 75)
+        adb.logcat()
+
 
 class GradlePackageCommand(GradleMixin, PackageCommand):
     description = "Create an Android App Bundle and APK in release mode."
@@ -213,11 +224,11 @@ class GradlePackageCommand(GradleMixin, PackageCommand):
                 # Windows needs the full path to `gradlew`; macOS & Linux can find it
                 # via `./gradlew`. For simplicity of implementation, we always provide
                 # the full path.
-                [str(self.gradlew_path(app)), "bundleRelease"],
+                [self.gradlew_path(app), "bundleRelease"],
                 env=self.android_sdk.env,
                 # Set working directory so gradle can use the app bundle path as its
                 # project root, i.e., to avoid 'Task bundleRelease not found'.
-                cwd=str(self.bundle_path(app)),
+                cwd=self.bundle_path(app),
                 check=True
             )
         except subprocess.CalledProcessError:
