@@ -62,8 +62,8 @@ def test_no_requested_size(create_command, tmp_path, capsys):
 
     # The file was copied into position
     create_command.shutil.copy.assert_called_with(
-        str(create_command.base_path / 'input' / 'original.png'),
-        str(out_path),
+        create_command.base_path / 'input' / 'original.png',
+        out_path,
     )
 
 
@@ -116,8 +116,8 @@ def test_requested_size(create_command, tmp_path, capsys):
 
     # The file was copied into position
     create_command.shutil.copy.assert_called_with(
-        str(create_command.base_path / 'input' / 'original-3742.png'),
-        str(out_path),
+        create_command.base_path / 'input' / 'original-3742.png',
+        out_path,
     )
 
 
@@ -172,8 +172,8 @@ def test_variant_with_no_requested_size(create_command, tmp_path, capsys):
 
     # The file was copied into position
     create_command.shutil.copy.assert_called_with(
-        str(create_command.base_path / 'input' / 'original.png'),
-        str(out_path),
+        create_command.base_path / 'input' / 'original.png',
+        out_path,
     )
 
 
@@ -264,8 +264,8 @@ def test_variant_with_size(create_command, tmp_path, capsys):
 
     # The file was copied into position
     create_command.shutil.copy.assert_called_with(
-        str(create_command.base_path / 'input' / 'original-3742.png'),
-        str(out_path),
+        create_command.base_path / 'input' / 'original-3742.png',
+        out_path,
     )
 
 
@@ -332,6 +332,6 @@ def test_unsized_variant(create_command, tmp_path, capsys):
 
     # The file was copied into position
     create_command.shutil.copy.assert_called_with(
-        str(create_command.base_path / 'input' / 'original.png'),
-        str(out_path),
+        create_command.base_path / 'input' / 'original.png',
+        out_path,
     )
