@@ -33,6 +33,9 @@ def test_new_app(new_command):
 
     # The right sequence of things will be done
     assert new_command.actions == [
+        # Tools are verified
+        ('verify', ),
+
         # Run the first app
-        ('new', {'template': None, 'input_enabled': True, 'verbosity': 1}),
+        ('new', {'template': None}),
     ]
