@@ -1,3 +1,4 @@
+import os
 import subprocess
 import sys
 from unittest import mock
@@ -116,25 +117,25 @@ def test_build_appimage(build_command, first_app, tmp_path):
     app_dir = tmp_path / 'linux' / 'appimage' / 'First App' / 'First App.AppDir'
     build_command._subprocess.run.assert_called_with(
         [
-            str(build_command.linuxdeploy.appimage_path),
+            os.fsdecode(build_command.linuxdeploy.appimage_path),
             "--appimage-extract-and-run",
             "--appdir={appdir}".format(appdir=app_dir),
-            "-d", str(app_dir / "com.example.first-app.desktop"),
+            "-d", os.fsdecode(app_dir / "com.example.first-app.desktop"),
             "-o", "appimage",
-            "--deploy-deps-only", str(app_dir / 'usr' / 'app' / 'support'),
-            "--deploy-deps-only", str(app_dir / 'usr' / 'app_packages' / 'firstlib'),
-            "--deploy-deps-only", str(app_dir / 'usr' / 'app_packages' / 'secondlib'),
+            "--deploy-deps-only", os.fsdecode(app_dir / 'usr' / 'app' / 'support'),
+            "--deploy-deps-only", os.fsdecode(app_dir / 'usr' / 'app_packages' / 'firstlib'),
+            "--deploy-deps-only", os.fsdecode(app_dir / 'usr' / 'app_packages' / 'secondlib'),
         ],
         env={
             'PATH': '/usr/local/bin:/usr/bin',
             'VERSION': '0.0.1',
         },
         check=True,
-        cwd=str(tmp_path / 'linux')
+        cwd=os.fsdecode(tmp_path / 'linux')
     )
     # Binary is marked executable
     build_command.os.chmod.assert_called_with(
-        str(tmp_path / 'linux' / 'First_App-0.0.1-wonky.AppImage'),
+        tmp_path / 'linux' / 'First_App-0.0.1-wonky.AppImage',
         0o755
     )
 
@@ -156,21 +157,21 @@ def test_build_failure(build_command, first_app, tmp_path):
     app_dir = tmp_path / 'linux' / 'appimage' / 'First App' / 'First App.AppDir'
     build_command._subprocess.run.assert_called_with(
         [
-            str(build_command.linuxdeploy.appimage_path),
+            os.fsdecode(build_command.linuxdeploy.appimage_path),
             "--appimage-extract-and-run",
             "--appdir={appdir}".format(appdir=app_dir),
-            "-d", str(app_dir / "com.example.first-app.desktop"),
+            "-d", os.fsdecode(app_dir / "com.example.first-app.desktop"),
             "-o", "appimage",
-            "--deploy-deps-only", str(app_dir / 'usr' / 'app' / 'support'),
-            "--deploy-deps-only", str(app_dir / 'usr' / 'app_packages' / 'firstlib'),
-            "--deploy-deps-only", str(app_dir / 'usr' / 'app_packages' / 'secondlib'),
+            "--deploy-deps-only", os.fsdecode(app_dir / 'usr' / 'app' / 'support'),
+            "--deploy-deps-only", os.fsdecode(app_dir / 'usr' / 'app_packages' / 'firstlib'),
+            "--deploy-deps-only", os.fsdecode(app_dir / 'usr' / 'app_packages' / 'secondlib'),
         ],
         env={
             'PATH': '/usr/local/bin:/usr/bin',
             'VERSION': '0.0.1',
         },
         check=True,
-        cwd=str(tmp_path / 'linux')
+        cwd=os.fsdecode(tmp_path / 'linux')
     )
 
     # chmod isn't invoked if the binary wasn't created.
@@ -217,10 +218,10 @@ def test_build_appimage_with_docker(build_command, first_app, tmp_path):
             "--deploy-deps-only", "/app/appimage/First App/First App.AppDir/usr/app_packages/secondlib",
         ],
         check=True,
-        cwd=str(tmp_path / 'linux')
+        cwd=os.fsdecode(tmp_path / 'linux')
     )
     # Binary is marked executable
     build_command.os.chmod.assert_called_with(
-        str(tmp_path / 'linux' / 'First_App-0.0.1-wonky.AppImage'),
+        tmp_path / 'linux' / 'First_App-0.0.1-wonky.AppImage',
         0o755
     )
